@@ -73,7 +73,7 @@ static struct icom_priv_caps icr8500_priv_caps =
 struct rig_caps icr8500_caps =
 {
     RIG_MODEL(RIG_MODEL_ICR8500),
-    .model_name = "ICR-8500",
+    .model_name = "IC-R8500",
     .mfg_name =  "Icom",
     .version =  BACKEND_VER ".0",
     .copyright =  "LGPL",
