@@ -5,7 +5,7 @@
  *
  *  10-03-2010
  *    Ported from Stephane Fillod's thf7.c
- *    Changed TH-F7E perameters to reflect TH-F6A
+ *    Changed TH-F7E parameters to reflect TH-F6A
  *    Changed RIG_ITU_REGION from 1 to 2
  *
  *
@@ -25,8 +25,6 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 
 #include <hamlib/rig.h>
@@ -114,7 +112,7 @@ static int thf6a_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op);
  * - set/get_ctcss_tone/sql through set/get_channel() and VR/VW
  * - emulate RIG_FUNC_TONE|RIG_FUNC_TSQL by setting ctcss_tone/sql to 0/non zero?
  */
-const struct rig_caps thf6a_caps =
+struct rig_caps thf6a_caps =
 {
     RIG_MODEL(RIG_MODEL_THF6A),
     .model_name = "TH-F6A",
