@@ -28,19 +28,14 @@
  * \brief Parallel Port IO
  * \file parallel.c
  */
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
+#include <hamlib/rig.h>
+#include <hamlib/config.h>
 
-#include <stdlib.h>
-#include <stdio.h>   /* Standard input/output definitions */
 #include <string.h>  /* String function definitions */
 #include <unistd.h>  /* UNIX standard function definitions */
 #include <fcntl.h>   /* File control definitions */
 #include <errno.h>   /* Error number definitions */
-#include <sys/time.h>
 #include <sys/types.h>
-#include <unistd.h>
 
 #ifdef HAVE_SYS_IOCTL_H
 #  include <sys/ioctl.h>
@@ -63,7 +58,6 @@
 #  include <winbase.h>
 #endif
 
-#include <hamlib/rig.h>
 #include "parallel.h"
 
 #ifdef HAVE_LINUX_PPDEV_H
